@@ -8,10 +8,11 @@ This class is for yaml-file deal
 
 """
 import yaml
+from benedict import benedict
 
 
 class yaml_tools:
-    def __init__(self, file_path: None) -> None:
+    def __init__(self, path="") -> None:
         """
         you should provide the file_path to use this tool.
         if file_path not found, will raise FileNotFoundError
@@ -22,9 +23,9 @@ class yaml_tools:
         :param: file_path
 
         """
-        if self.path is None:
+        if path is None:
             raise FileNotFoundError(" The file is not exist!")
-        self.path = file_path
+        self.path = path
 
     def yaml_to_dict(self) -> dict:
         """
@@ -32,14 +33,19 @@ class yaml_tools:
 
         """
         with open(self.path, "r") as f:
+
             yaml_file = yaml.safe_load(f)
         return yaml_file
 
-    def get_config_by_name(self, config_name: None) -> str:
+    def get_config_by_name(self, config_name=""):
         """
         use get method to get the string words
 
         :param:config_name
         :return:String
         """
-        return self.yaml_to_dict().get(config_name)
+        print(self.yaml_to_dict())
+        dic = benedict(self.yaml_to_dict())
+        return dic[config_name]
+
+    # TODO 添加文件内容的异常处理
